package fr.she3py.worldpopulation;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.bukkit.Bukkit;
import org.bukkit.configuration.ConfigurationSection;
import org.bukkit.entity.Player;
import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import me.clip.placeholderapi.expansion.Cacheable;
import me.clip.placeholderapi.expansion.PlaceholderExpansion;

public class WorldPopulationExpansion extends PlaceholderExpansion implements Cacheable {
	@NonNls
	private final Map<String, List<String>> regions = new HashMap<>();
	
	@Override
	public boolean canRegister() {
		ConfigurationSection config = this.getConfigSection();
		if(config == null) {
			this.warning("The expansion configuration section is missing!");
			
			return true;
		}
		
		for(String key : config.getKeys(false)) {
			this.regions.put("of_" + key, config.getStringList(key));
		}
		
		return true;
	}
	
	@Override
	public void clear() {
		this.regions.clear();
	}
	
	@Override
	@Nullable
	public String onPlaceholderRequest(Player player, @NotNull String params) {
		List<String> worlds = this.regions.get(params);
		if(worlds != null) {
			int population = worlds.stream().map(Bukkit::getWorld).mapToInt(w -> w == null ? 0 : w.getPlayers().size()).sum();
			
			return String.valueOf(population);
		}
		
		//noinspection StringConcatenation,MagicCharacter
		return "unknown population: `" + params + '`';
	}
	
	@Override
	@NotNull
	public String getName() {
		return "world-population";
	}
	
	@Override
	@NotNull
	public String getIdentifier() {
		return "population";
	}
	
	@Override
	@NotNull
	public String getAuthor() {
		return "ShE3py";
	}
	
	@Override
	@NotNull
	public String getVersion() {
		return "1.0.0";
	}
}
